@@ -56,12 +56,12 @@ It is being written by U{Arne Babenhauserheide <http://draketo.de>}. If you wish
 Usage of this module
 ====================
 
-    >>> # from magma import Magma
-    >>> magma = Magma(magma_file="example-0.4.magma")
+    >>> # from magma import *
+    >>> mag = open_file("example-0.4.magma")
 
 or 
 
-    >>> magma = Magma(input_files=["input_file.txt", "input_file2.txt"])    
+    >>> mag = Magma(input_files=["input_file.txt", "input_file2.txt"])    
 
 
 API / usage
@@ -70,13 +70,10 @@ API / usage
 B{Creating magma lists from input files}
     
 Create a list from input files. 
-    >>> magma = Magma(input_files=["input_file.txt"])
+    >>> mag = create_from_input_files(["input_file.txt"])
     
-And save the list. 
-    >>> magma.save(path="example.magma")
-    
-Or output the it. 
-    >>> print magma
+Output the list, showing the empty entries, which could be filled with data. 
+    >>> print mag
     #MAGMAv0.4
     files:
     - filename: input_file.txt
@@ -86,23 +83,30 @@ Or output the it.
       urn:
         sha1: 3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G
     <BLANKLINE>
+    # Magmav0.2 compatibility section
+    list:
+     - "magnet:?dn=input_file.txt&xt=urn%3Asha1%3A3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G"
+    <BLANKLINE>
+    
+And save it to a file with the empty entries cleaned away. 
+    >>> mag.save(path="example.magma")
 
 
 Or just return a list of its files as MagmaFiles. 
-    >>> files = magma.files
+    >>> files = mag.files
     
 Or output all magnet links inside the magma list. 
-   >>> print magma.magnets
+   >>> print mag.magnets
    ['magnet:?dn=input_file.txt&xt=urn%3Asha1%3A3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G']
   
   
 B{Reading from magma lists}
    
-Create the list. 
-   >>> magma = Magma(magma_file="example.magma")
+Readout the data from a file. 
+   >>> mag = open_file("example.magma")
    
-Now get the files
-   >>> files = magma.files
+Now get the files inside the list. 
+   >>> files = mag.files
    >>> for i in files: print i
    input_file.txt 3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G
    
@@ -121,37 +125,36 @@ Or output all its (meta-) data.
    
 
 Output all magnet links inside the magma list. 
-   >>> print magma.magnets
+   >>> print mag.magnets
    ['magnet:?dn=input_file.txt&xt=urn%3Asha1%3A3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G']
 
 Load a Magma object from a string containing Magma data via magma.load(). 
 As test, load a minimal Magma file, containing nothing but the header.
-   >>> magma = load("#MAGMAv0.4")
+   >>> mag = load("#MAGMAv0.4")
    
 And cry out, if the string doesn't begin with the Magma header (isn't Magma data!). 
-   >>> magma = load("a:b")
+   >>> mag = load("a:b")
    Traceback (most recent call last):
    ...
    AssertionError: Doesn't begin with Magma v0.4 header #MAGMAv0.4
 
 Also dump yaml data via magma.dump()
-   >>> print dump(magma)
+   >>> print dump(mag)
    #MAGMAv0.4
    {}
    <BLANKLINE>
+   # Magmav0.2 compatibility section
+   list:
+   <BLANKLINE>
 
-Or just open a Magma file from its path. 
-    >>> magma = open_file("example.magma")
-    >>> print magma
-    #MAGMAv0.4
-    files:
-    - filename: input_file.txt
-      gnutella:
-        alt-locs: []
-      urls: []
-      urn:
-        sha1: 3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G
-    <BLANKLINE>
+Or just print the Magma data. 
+   >>> print mag
+   #MAGMAv0.4
+   {}
+   <BLANKLINE>
+   # Magmav0.2 compatibility section
+   list:
+   <BLANKLINE>
 
 
 Plans: Gnutella
@@ -159,12 +162,12 @@ Plans: Gnutella
     - Add Alt-locs (depends on the network used). Maybe GNet-Alt-Loc for Gnutella. Gets parsed to magnet xs automatically. 
    
 Ideas: 
+    - Readout metadata from files, for example using the taglib, pyPdf or such. 
     - If given both magma list and files, the magma list gets extended by the files. 
     - Joining and seperating magma lists. 
     - Passing several additional input lists to join with the main list. 
     - Passing the data of files along with magma metadata to create the list. 
     - Passing the indizes of files to automatically slice the list. maybe even with the syntax sliced_magma = magma[a:b]
-    - Readout metadata from files, for example using the taglib, pyPdf or such. 
     - If a dir gets passed, add all files within that dir. Alsa a parameter to ask, if it should be done recursively. 
     - If hashing files takes very long (for example seen with clock.tick()), give more output. 
     - Add more commandline switches (verbose, help, ... - see the babtools_gentoo script)
@@ -178,7 +181,7 @@ __copyright__ = 'Copyright (C) 2008 Arne Babenhauserheide'
 __date__ = '2008-05-09'
 __licence__ = 'GPL-3 or later'
 __program__ = 'MAGnet MAnifest Management'
-__version__ = '0.3.4'
+__version__ = '0.3.5'
 
 # The dependencies of the _init__ only. 
 __depends__ = ''
@@ -225,12 +228,20 @@ from magma_list import Magma
 def open_file(filepath):
     """Open a file as Magma list and produce the corresponding Python object.
     
-    @param yaml_data: Data read from a yaml file
+    @param yaml_data: Data read from a yaml file. 
     @type yaml_data: String
     @return: A Magma Object. 
     """
     return Magma(magma_file=filepath)
 
+def create_from_input_files(files):
+    """Create a magma file from given input files.
+    
+    @param files: A list of file paths
+    @type files: List of Strings
+    @return: A Magma Object."""
+    return Magma(input_files=files)
+
 def load(yaml_data):
     """Parse a Magma list and produce the corresponding Python object.
     
