@@ -88,7 +88,7 @@ class Magma(object):
             self.data["creator"] = creator
         
         #: All files inside the Magma list. 
-        self.files = self.readout_files()
+        self.files = self.files()
         
         #: All magnets inside the Magma list. 
         self.magnets = self.get_file_magnets()
@@ -102,8 +102,19 @@ class Magma(object):
         In effect return the yaml data with the magic header.
         
         @return: A human readable representation of the Magma file in yaml format (String)."""
-        return "#MAGMAv0.4" + "\n" + self.get_yaml_data()
+        # Then return its Magma representation (Magma Header + yaml data). 
+        return self.dump()
         
+    
+    def remove_empty_entries(self): 
+        """Remove empty entries in the Magma, for example empty alt-locs.
+        
+        We remove each entry by hand, because we should know which entries can be created by this program - and if we don't we know that have to change our coding practice :) ."""
+        
+        # Just tell every file to clean itself. 
+        for i in self.files: 
+            i.remove_empty_entries()
+            
     def create_magma_from_files(self, file_paths): 
         """Create a magma file from given file paths. 
         
@@ -156,7 +167,7 @@ class Magma(object):
         # At the end, return the data. 
         return self.readout_yaml(file_data)
         
-    def readout_files(self):
+    def files(self):
         """Get the files from the magma data
         
         @return: A list of all MagmaFile objects from the Magma.
@@ -176,7 +187,7 @@ class Magma(object):
     def get_file_magnets(self): 
         """Get the magnet links of the files.
        
-	# TODO: Include Alt-Locs. 
+        # TODO: Include Alt-Locs. 
 
         @return: A list of all magnet links inside the Magma.
         """
@@ -200,23 +211,51 @@ class Magma(object):
                 magma_metadata[i] = self.data[i]
         # That's it. 
         return magma_metadata
+    
+    def magma_v0_2_filelist_representation(self):
+        """@return: A list of files which can be read by MAGMAv0.2 compliant programs."""
+        # First we get the list parameter. 
+        data = "list:\n"
         
-    def save(self, path):
+        # Then we append a magnet for each file. 
+        for i in self.files: 
+            data += ' - "' + i.magnet + '"\n'
+        
+        return data
+    
+    def magma_v0_2_data(self): 
+        """@return: Data in Magma v0.2 format"""
+        # First we begin with the MAGMAV0.2 header line. 
+        data = "#MAGMAv0.2\n"
+        
+        # Then we append the file list. 
+        data += magma_v0_2_filelist_representation()
+        
+        return data
+        
+        
+    def save(self, path, magma_versions = [0.2, 0.4]):
         """Save the magma list to the path. 
         
         If the folder to save in doesn't exist, just raise an Exception.
         
-	TODO: Clean out empty entries in the files and the metadata before saving. 
-	self.data["gnutella"]["alt-locs"] = [] should disappear (if there are no other keys than alt-locs in gnutella, the gnutella dict should completely disappear, too). 
+        TODO: Clean out empty entries in the files and the metadata before saving. 
+        self.data["gnutella"]["alt-locs"] = [] should disappear (if there are no other keys than alt-locs in gnutella, the gnutella dict should completely disappear, too). 
 
         @param path: The path to the target file.
         @type path: String
+        
+        @param magma_versions: The versions of the magma specification to be supported. 
+        @type magma_versions: List of Floats
+    
         @return: None
         """
+        # First remove empty entries, so we get a nice looking file. 
+        self.remove_empty_entries()
         # First get the file handle for the magma file
         file_handle = open(path, "w")
         # Then write the data in yaml format. 
-        file_handle.write(self.dump())
+        file_handle.write(self.dump(magma_versions=magma_versions))
         # And close the file handle. 
         file_handle.close()
         
@@ -234,12 +273,20 @@ class Magma(object):
         @return: The yaml representation of the data."""
         return dump(self.data, default_flow_style=False)
         
-    def dump(self):
+    def dump(self, magma_versions = [0.2, 0.4]):
         """Return the yaml data. 
         
         @return: A string representation of the Magma in yaml format.
         """
-        return "#MAGMAv0.4\n" + self.get_yaml_data()
+        # If we want 0.2 support, we add it. 
+        if 0.2 in magma_versions and 0.4 in magma_versions: 
+            # But first we remove the former 0.2 list. 
+            if "list" in self.data.keys(): 
+                del(self.data["list"])
+            # Now we add a new list from the data we got. This can REMOVE DEPRECATED DATA. 
+            return "#MAGMAv0.4\n" + self.get_yaml_data() + "\n# Magmav0.2 compatibility section\n" + self.magma_v0_2_filelist_representation()
+        elif 0.4 in magma_versions: 
+            return "#MAGMAv0.4\n" + self.get_yaml_data()
 
 
 # Also we have files inside the magma list. They hate a few extra attributes to be easier to use than raw dictionaries. 
@@ -334,6 +381,33 @@ class MagmaFile(object):
         magnet = "magnet:?" + urlencode(params)
         # TODO: Include alt-locs. 
         return magnet
+    
+    
+    def remove_empty_entries(self): 
+        """Remove empty entries from the file, for example empty alt-locs."""
+        # Check each key, if it points to an empty dictionary, or only to empty subelements. 
+        
+        # First check for empty subkeys. 
+        for i in self.data: 
+            try: 
+                # Iterate over the items inside the key
+                for j in self.data[i].keys(): 
+                    try: 
+                        # if it has a length and the length is 0, we remove it. 
+                        if len(self.data[i][j]) == 0: 
+                            del(self.data[i][j])
+                    except: pass
+            except: pass
+        
+        # Now  check for empty keys. 
+        for i in self.data.keys(): 
+            try: 
+                # If the length of the thing is 0, the whatever-it-is empty and we can remove it. 
+                if len(self.data[i]) == 0: 
+                    del(self.data[i])
+            except: # If we can't get a length, we just ignore it. It seems to be data/content, not structure. 
+                pass
+        #TODO: Make this rekursive, so we can clean arbitrary deeply nested structures. 
 
 
 def usage(): 
